@@ -1,4 +1,4 @@
-// $Revision: 1.17 $$Date: 2005-03-01 17:59:56 -0500 (Tue, 01 Mar 2005) $$Author: wsnyder $
+// $Revision: 1.17 $$Date: 2005-03-11 16:38:41 -0500 (Fri, 11 Mar 2005) $$Author: wsnyder $
 // DESCRIPTION: SystemPerl: Example main()
 //
 // Copyright 2001-2005 by Wilson Snyder.  This program is free software;
@@ -9,16 +9,22 @@
 #include <sys/types.h>
 
 #include <systemperl.h>
-#include "sp_log.h"
 #include "ExBench.h"
-#include "SpTraceVcd.h"
+
+#ifndef NC_SYSTEMC
+# include "sp_log.h"
+# include "SpTraceVcd.h"
+#endif
 #include "SpCoverage.h"
 
 int sc_main (int argc, char *argv[]) {
+
+#ifndef NC_SYSTEMC
     // Simulation logfile
     sp_log_file splog;
     splog.open ("sim.log");
     splog.redirect_cout();
+#endif
 
     // Pins
     sc_clock clk("clk",10);
@@ -28,17 +34,20 @@ int sc_main (int argc, char *argv[]) {
     SP_PIN  (bench,clk,clk);
     bench->configure();	// Verify the #sp include worked
 
+#ifndef NC_SYSTEMC
     sc_initialize();
+#endif
 
     // Example enumeration usage
     MyENumClass enval = MyENumClass::ONE;
     cout << "enval = "<<enval<<endl;	// Prints "ONE"
 
+#ifndef NC_SYSTEMC
     // SystemC traces are flawed, you can't even trace ports
     sc_trace_file *tf = sc_create_vcd_trace_file("sim_sc" );
-#ifndef _SC_LITE_
+# ifndef _SC_LITE_
     sc_trace(tf, clk, "clk");
-#endif
+# endif
 
     // SystemPerl traces
     SpTraceFile* stp = new SpTraceFile;
@@ -51,13 +60,16 @@ int sc_main (int argc, char *argv[]) {
     stp2->rolloverMB(1);	// Rollover logfiles when size > 1MB
     bench->trace(stp2,999);
     stp2->open("sim_sp2.vcd");
+#endif
 
     cout << "Starting\n";
     sc_start(-1);
     cout << "Done\n";
 
+#ifndef NC_SYSTEMC
     sc_close_vcd_trace_file(tf);
     SpTraceVcd::flush_all();
+#endif
 
     // Coverage
     mkdir("logs", 0777);
