@@ -1,4 +1,4 @@
-// $Revision: 1.4 $$Date: 2005-03-01 17:59:56 -0500 (Tue, 01 Mar 2005) $$Author: wsnyder $ -*- SystemC -*-
+// $Revision: 1.4 $$Date: 2005-03-02 11:20:22 -0500 (Wed, 02 Mar 2005) $$Author: wsnyder $ -*- SystemC -*-
 //=============================================================================
 //
 // THIS MODULE IS PUBLICLY LICENSED
@@ -184,6 +184,21 @@ void SpTraceVcd::bufferFlush () {
     m_writep = m_wrBufp;
 }
 
+//=============================================================================
+// Simple methods
+
+void SpTraceVcd::set_time_unit (const char* unit) {
+    string unitstr (unit);
+    if (!isdigit(unitstr[0])) unitstr = "1"+unitstr;
+    m_timeUnit = unitstr;
+}
+
+void SpTraceVcd::set_time_resolution (const char* unit) {
+    string unitstr (unit);
+    if (!isdigit(unitstr[0])) unitstr = "1"+unitstr;
+    m_timeRes = unitstr;
+}
+
 //=============================================================================
 // Definitions
 
@@ -198,7 +213,10 @@ void SpTraceVcd::dumpHeader () {
     printStr("$version Generated by SpTraceVcd $end\n");
     time_t time_str = time(NULL);
     printStr("$date "); printStr(ctime(&time_str)); printStr(" $end\n");
-    printStr("$timescale 1ns/1ns $end\n");
+
+    printStr("$timescale ");
+    printStr(m_timeUnit.c_str()); printStr("/"); printStr(m_timeRes.c_str());
+    printStr(" $end\n");
 
     // Take signal information from each module and build m_namemapp
     m_namemapp = new NameMap;
